@@ -62,15 +62,17 @@ static void e_webcal_label_size_allocate_cb (GtkWidget *widget,
 					     gpointer user_data) {
   gint width, height;
   GtkWidget *label;
+  GtkAllocation current_allocation;
 
   label = user_data;
 
   gtk_widget_get_size_request (label, &width, &height);
+  gtk_widget_get_allocation (label, &current_allocation);
 
   if (allocation->width > 1 &&
-      allocation->width != (width + label->allocation.x)) {
+      allocation->width != (width + current_allocation.x)) {
     gtk_widget_set_size_request (label,
-				 allocation->width - label->allocation.x,
+				 allocation->width - current_allocation.x,
 				 -1);
     gtk_container_check_resize (GTK_CONTAINER (widget));
   }
@@ -89,14 +91,9 @@ static void e_webcal_icon_theme_changed (GtkIconTheme * theme,
 				"x-office-calendar", GTK_ICON_SIZE_DIALOG);
 }
 
-static void e_webcal_change_adjustment (GtkMenuShell * shell,
-					GtkWidget * spinner) {
-  GtkWidget * widget;
-
-  widget = gtk_menu_get_active (GTK_MENU (shell));
-
-  if (widget != NULL) {
-    switch (g_list_index (shell->children, widget)) {
+static void e_webcal_change_adjustment (GtkComboBox * combo,
+                                       GtkWidget * spinner) {
+  switch (gtk_combo_box_get_active (combo)) {
     case E_ICALSHARE_TIMEOUT_DAYS:
       gtk_spin_button_set_range (GTK_SPIN_BUTTON (spinner), 1, 6);
       gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinner), 1);
@@ -113,30 +110,16 @@ static void e_webcal_change_adjustment (GtkMenuShell * shell,
       gtk_spin_button_set_range (GTK_SPIN_BUTTON (spinner), 1, 23);
       gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinner), 1);
       break;
-    }
   }
 }
 
-static gint e_webcal_option_menu_get (GtkOptionMenu * menu) {
-  GtkWidget * widget;
-
-  g_return_val_if_fail (GTK_IS_OPTION_MENU (menu), -1);
-
-  widget = gtk_menu_get_active (GTK_MENU (menu->menu));
-
-  if (widget != NULL) {
-    return g_list_index (GTK_MENU_SHELL (menu->menu)->children, widget);
-  }
-
-  return -1;
-}
-
 void e_webcal_display_error (const gchar * title, const gchar * message,
 			     GtkWidget * parent) {
   GtkWidget * dialog;
   GtkWidget * label;
   GtkWidget * image;
   GtkWidget * hbox, * vbox;
+  GtkWidget * dialog_vbox;
   GdkPixbuf * pixbuf;
   gchar * markup;
 
@@ -161,14 +144,15 @@ void e_webcal_display_error (const gchar * title, const gchar * message,
   gtk_window_set_icon (GTK_WINDOW (dialog), pixbuf);
   g_object_unref (pixbuf);
 
-  gdk_window_set_decorations (GDK_WINDOW (dialog->window), GDK_DECOR_BORDER);
+  gdk_window_set_decorations (gtk_widget_get_window (dialog), GDK_DECOR_BORDER);
 
-  gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->action_area), 12);
-  gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), 0);
+  dialog_vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
+  gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (dialog))), 12);
+  gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 0);
   hbox = gtk_hbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
-		      TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
   image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_ERROR,
@@ -234,13 +218,13 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
                           gboolean has_events, gboolean has_tasks) {
   EIcalShareDialog * dialog;
   GtkObject * spinadj;
-  GtkWidget * tspinb, * toption;
-  GtkWidget * menu, * mitem;
+  GtkWidget * tspinb, * combo;
   GtkWidget * vbox, * hbox;
   GtkWidget * lbox, * wbox, * xbox;
   GtkWidget * rlabel, * clabel;
   GtkWidget * cbutton;
   GtkWidget * label, * button;
+  GtkWidget * dialog_actionarea, * dialog_vbox;
   SoupURI * tmpuri;
   gchar * tmpname;
   gchar * mrkname, * ref_str;
@@ -252,19 +236,20 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   GdkColor color;
   GSList * l;
   gchar * scolor;
-  guint32 icolor = 0;
 
   tmpuri = soup_uri_new (caluri);
   tmpname = g_path_get_basename (tmpuri->path);
 
   /* If we are already subscribed, pop up an error dialog */
   if (!has_events && !has_tasks) {
-    gchar * msg;
+    gchar * msg, * title;
 
     msg = g_strdup_printf (_("No events or tasks were found in the calendar "
 			     "\"%s\"."),
 			   name ? name : tmpname);
-    e_webcal_display_error (_("<b>No Tasks or Events Found</b>"), msg, NULL);
+    title = g_strdup_printf ("<b>%s</b>", _("No Tasks or Events Found"));
+    e_webcal_display_error (title, msg, NULL);
+    g_free (title);
     g_free (msg);
 
     g_free (tmpname);
@@ -318,12 +303,14 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
 
   /* If we are already subscribed, pop up an error dialog */
   if (!has_events && !has_tasks) {
-    gchar * msg;
+    gchar * msg, * title;
 
     msg = g_strdup_printf (_("You are already subscribed to the calendar "
 			     "\"%s\". Please subscribe to another calendar."),
 			   name ? name : tmpname);
-    e_webcal_display_error (_("<b>Already Subscribed</b>"), msg, NULL);
+    title = g_strdup_printf ("<b>%s</b>", _("Already Subscribed"));
+    e_webcal_display_error (title, msg, NULL);
+    g_free (title);
     g_free (msg);
 
     g_free (tmpname);
@@ -356,9 +343,11 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   gtk_widget_realize (dialog->dialog);
 
   /* More Sane than Stupid Pet Tricks */
-  gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog->dialog)->action_area), 12);
-  gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog->dialog)->vbox), 0);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog->dialog)->action_area), 6);
+  dialog_actionarea = gtk_dialog_get_action_area (GTK_DIALOG (dialog->dialog));
+  dialog_vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog->dialog));
+  gtk_container_set_border_width (GTK_CONTAINER (dialog_actionarea), 12);
+  gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 0);
+  gtk_box_set_spacing (GTK_BOX (dialog_actionarea), 6);
 
   /* Dialog Buttons */
   /*
@@ -397,8 +386,7 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   /* Main Box */
   hbox = gtk_hbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox), hbox,
-		      TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
   /* Lame Box for Pretty Icon so It is Top-aligned */
@@ -474,36 +462,22 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
 
   gtk_label_set_mnemonic_widget (GTK_LABEL (rlabel), tspinb);
 
-  toption = gtk_option_menu_new ();
-  gtk_box_pack_start (GTK_BOX (hbox), toption, FALSE, FALSE, 0);
-  gtk_widget_show (toption);
+  combo = gtk_combo_box_new_text ();
+  gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
+  gtk_widget_show (combo);
 
-  menu = gtk_menu_new ();
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Days"));
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Hours"));
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Minutes"));
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Weeks"));
 
-  mitem = gtk_menu_item_new_with_label (_("Days"));
-  gtk_menu_shell_append (GTK_MENU_SHELL (menu), mitem);
-  gtk_widget_show (mitem);
-
-  mitem = gtk_menu_item_new_with_label (_("Hours"));
-  gtk_menu_shell_append (GTK_MENU_SHELL (menu), mitem);
-  gtk_widget_show (mitem);
-
-  mitem = gtk_menu_item_new_with_label (_("Minutes"));
-  gtk_menu_shell_append (GTK_MENU_SHELL (menu), mitem);
-  gtk_widget_show (mitem);
-
-  mitem = gtk_menu_item_new_with_label (_("Weeks"));
-  gtk_menu_shell_append (GTK_MENU_SHELL (menu), mitem);
-  gtk_widget_show (mitem);
-
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (toption), menu);
-  gtk_option_menu_set_history (GTK_OPTION_MENU (toption),
-			       E_ICALSHARE_TIMEOUT_HOURS);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo),
+                           E_ICALSHARE_TIMEOUT_HOURS);
 
   /* If the user changes the units of time, we want to update the spin
      button with more appropriate ranges for the time to refresh */
-  g_signal_connect (G_OBJECT (menu), "deactivate",
-		    G_CALLBACK (e_webcal_change_adjustment), tspinb);
+  g_signal_connect (combo, "changed",
+                   G_CALLBACK (e_webcal_change_adjustment), tspinb);
 
   /* Color button for the calendar properties */
   hbox = gtk_hbox_new (FALSE, 6);
@@ -528,7 +502,7 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   case GTK_RESPONSE_HELP:
     break;
   case GTK_RESPONSE_OK:
-    switch (e_webcal_option_menu_get (GTK_OPTION_MENU (toption))) {
+    switch (gtk_combo_box_get_active (GTK_COMBO_BOX (combo))) {
     case E_ICALSHARE_TIMEOUT_DAYS:
       ref_multi = 1440;
       break;
@@ -548,8 +522,9 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
     g_free (ref_str);
 
     gtk_color_button_get_color (GTK_COLOR_BUTTON (cbutton), &color);
-    icolor = ((color.red >> 8) << 16) | ((color.green >> 8) << 8) | (color.blue >> 8);
-    e_source_set_color (source, icolor);
+    scolor = gdk_color_to_string (&color);
+    e_source_set_color_spec (source, scolor);
+    g_free (scolor);
 
     if (!strncmp (caluri, WEBCAL_BASE_URI, 9)) {
       e_source_set_relative_uri (source, caluri + 9);
